import{C as p}from"./controller.ba0b57fd.js";import{d as i,ef as n,o as a,c as s,u as m}from"./index.a1506152.js";import{_ as d}from"./View.vue_vue_type_script_setup_true_lang.020fd9d1.js";import"./gateway.36e126ca.js";import"./popupNotifcation.7c2101f3.js";import"./fetch.8f81a728.js";import"./record.d6bf7292.js";import"./PhPencil.vue.34413cfd.js";import"./SaveButton.2182dde6.js";import"./UnsavedChangesHandler.f60d6853.js";import"./ExclamationCircleOutlined.37c8ef64.js";import"./CrudView.d781e8fd.js";import"./router.2d44d6fc.js";import"./Badge.07d26512.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.30c09690.js";import"./BookOutlined.989c2e9e.js";import"./url.e9cfa1d3.js";import"./PhDotsThreeVertical.vue.0cdf9efb.js";import"./index.a25bcd68.js";import"./index.4f812115.js";import"./asyncComputed.5f4a7018.js";import"./polling.efadd48a.js";import"./index.aeb74054.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="7f8ca1de-2aad-4aa1-bb6d-7cfb930ce2be",o._sentryDebugIdIdentifier="sentry-dbid-7f8ca1de-2aad-4aa1-bb6d-7cfb930ce2be")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(c,f)=>(a(),s(d,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.f4a5090e.js.map
