import{P as m}from"./PlayerNavbar.86329b10.js";import{d as g,eH as h,ef as i,e as y,f as b,r as k,o as c,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.a1506152.js";import{u as V}from"./workspaceStore.ee989c1a.js";import"./metadata.fcd21e8c.js";import"./PhRobot.vue.189c1747.js";import"./PhWebhooksLogo.vue.462865ef.js";import"./LoadingOutlined.6f9522c1.js";import"./PhSignOut.vue.0c72747b.js";import"./index.ba0d88c1.js";import"./Avatar.52002437.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="4a9f9e87-e865-49f2-be6e-9dfaad99c13b",o._sentryDebugIdIdentifier="sentry-dbid-4a9f9e87-e865-49f2-be6e-9dfaad99c13b")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=i().path,a=y(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=k("RouterView");return c(),v("div",x,[n(t).state.workspace?(c(),w(m,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(f)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.4c4785ea.js.map
