import{C as t,E as d,K as i,a as f,M as c,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.ffd27d86.js";import"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="17ea271b-7780-498f-8e9c-610a4f1a8d3d",e._sentryDebugIdIdentifier="sentry-dbid-17ea271b-7780-498f-8e9c-610a4f1a8d3d")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,f as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.ce14e7d9.js.map
