.source-code-container[data-v-c67d72b6]{display:flex;flex-direction:column;gap:10px;height:100%;overflow:hidden;position:relative;box-sizing:border-box;border-radius:8px}.source-code-container .file-input[data-v-c67d72b6]{margin-bottom:0;flex-grow:1}.source-code-container .monaco-element[data-v-c67d72b6]{height:100%}.source-code-container .monaco-element.hide[data-v-c67d72b6]{display:none}.source-code-container .monaco-element.blur[data-v-c67d72b6]{filter:blur(8px);pointer-events:none}.source-code-container .code-container[data-v-c67d72b6]{width:100%;height:100%;position:relative;border:1px solid lightgray;border-radius:8px}.source-code-container .not-found-container[data-v-c67d72b6]{position:absolute;z-index:2;width:100%;height:100%;display:flex;justify-content:center;align-items:center}.source-code-container .clickable[data-v-c67d72b6]{cursor:pointer;display:flex;align-items:center;gap:8px}.source-code-container[data-v-c67d72b6] .executing-line{background-color:#0000ff1a;border:1px solid blue}.source-code-container[data-v-c67d72b6] .error-line{background-color:#ff00001a;border:1px solid orangered}
