import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.73f3e4d8.js";import{d as m,eH as f,ef as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.a1506152.js";import{u as h}from"./workspaceStore.ee989c1a.js";import"./CircularLoading.a3ccc2be.js";import"./Logo.aea2420c.js";import"./string.a9f2e2e2.js";import"./index.aeb74054.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2ade1306-d7f8-48b9-be91-515a2378d441",e._sentryDebugIdIdentifier="sentry-dbid-2ade1306-d7f8-48b9-be91-515a2378d441")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,u,p,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(u=n(r).state.workspace)==null?void 0:u.brandName,locale:(i=(p=n(r).state.workspace)==null?void 0:p.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const S=k(I,[["__scopeId","data-v-cb33c596"]]);export{S as default};
//# sourceMappingURL=Login.59bdde2f.js.map
