import{d as i,en as c,f as r,o,Y as t,S as d,ee as f,ea as p,a0 as u}from"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="474a9c09-9fef-4be0-baba-30868c42d4d8",e._sentryDebugIdIdentifier="sentry-dbid-474a9c09-9fef-4be0-baba-30868c42d4d8")}catch{}})();const _={class:"logo"},g=["src","alt"],m=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;c(s=>({"4521d904":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),l=r(()=>`${a.brandName} Logo`);return(s,b)=>(o(),t("div",_,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:l.value},null,8,g)):d("",!0),s.hideText?d("",!0):(o(),t("span",{key:1,class:f(s.size)},p(s.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.aea2420c.js.map
