import{k as i,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as m,t as u,v as b}from"./index.a1506152.js";import{s as g,c as y,a}from"./workspaceStore.ee989c1a.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.4e87d4f2.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";import"./PlayerConfigProvider.9f6f394b.js";import"./index.6a4da8c3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4452d30e-59a2-4ba8-babf-3eb4adc981f3",t._sentryDebugIdIdentifier="sentry-dbid-4452d30e-59a2-4ba8-babf-3eb4adc981f3")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=i({render:()=>f(l)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,m),s(e,u),s(e,b)})();
//# sourceMappingURL=player.4f2a735c.js.map
