import{_ as y}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.c988a607.js";import{C as h}from"./ContentLayout.b536adcf.js";import{l as w}from"./fetch.8f81a728.js";import{d as b,eH as g,ef as k,e as v,o as r,c,w as n,b as f,a as C,u as i,d9 as p,aG as _,a0 as x}from"./index.a1506152.js";import{u as I,E as T}from"./editor.9a1ed41d.js";import{C as D}from"./Card.9e8c0424.js";import"./Logo.aea2420c.js";import"./workspaceStore.ee989c1a.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";import"./linters.93616ccb.js";import"./asyncComputed.5f4a7018.js";import"./TabPane.15ef770b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1fc1741f-024a-4c05-a303-9af8e9781033",e._sentryDebugIdIdentifier="sentry-dbid-1fc1741f-024a-4c05-a303-9af8e9781033")}catch{}})();const L={class:"card-content"},N=b({__name:"Welcome",setup(e){const o=g(),{query:d}=k(),a=I();a.loadLogin();const l=v(!0),u=async()=>{l.value=!1,setInterval(()=>{var t;return window.location.replace(((t=a==null?void 0:a.links)==null?void 0:t.project)||T.consoleUrl)},5e3)};return(async()=>{const t=d.token,s=await w("/_editor/web-editor/welcome",{method:"POST",body:JSON.stringify({token:t}),headers:{"Content-Type":"application/json"}});if(!s.ok)return u();const{ok:m}=await s.json();if(!m)return u();await o.push({name:"workspace"})})(),(t,s)=>(r(),c(h,null,{default:n(()=>[f(i(D),{bordered:!1,class:"card"},{default:n(()=>[C("div",L,[f(y,{style:{"margin-bottom":"10px"}}),l.value?(r(),c(i(p),{key:0},{default:n(()=>[_("Loading...")]),_:1})):(r(),c(i(p),{key:1},{default:n(()=>[_("Authentication failed. You are been redirected...")]),_:1}))])]),_:1})]),_:1}))}});const H=x(N,[["__scopeId","data-v-a984ec04"]]);export{H as default};
//# sourceMappingURL=Welcome.6e954882.js.map
