import{O as r}from"./workspaceStore.ee989c1a.js";import{d as c,X as l,o as i,Y as u,b as a,w as o,u as n,aG as d,dd as f,dc as _}from"./index.a1506152.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4dfcb36c-cc0e-4d6f-a901-65ce949e69f0",e._sentryDebugIdIdentifier="sentry-dbid-4dfcb36c-cc0e-4d6f-a901-65ce949e69f0")}catch{}})();const w=c({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(_),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.5674e27e.js.map
