import"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="8cb64beb-a833-41a3-98e6-02e9c5af6747",e._sentryDebugIdIdentifier="sentry-dbid-8cb64beb-a833-41a3-98e6-02e9c5af6747")}catch{}})();const o=e=>{try{return new URL(e),!0}catch{return!1}},i=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([a,s])=>{t.searchParams.delete(a),n.set(a,s)}),`${t.origin}${t.pathname}?${n.toString()}`};export{o as i,i as m};
//# sourceMappingURL=url.e9cfa1d3.js.map
