import{d as a,o as n,Y as s,a as d,$ as r,ee as l,a0 as f}from"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3ff8a11f-2a25-4bf9-b148-766c7a89a58c",e._sentryDebugIdIdentifier="sentry-dbid-3ff8a11f-2a25-4bf9-b148-766c7a89a58c")}catch{}})();const c={class:"content-layout"},_=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(n(),s("div",c,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=f(_,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.b536adcf.js.map
