import{d as t,o,Y as s,b as d,u as r,by as _,a0 as c}from"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b7a92657-307f-4a85-8ec2-79e5a0dfc952",e._sentryDebugIdIdentifier="sentry-dbid-b7a92657-307f-4a85-8ec2-79e5a0dfc952")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.22346283.js.map
