import{U as f,dA as s,dB as d}from"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="44a2fb6c-fa8b-413f-835c-15f4ddf0b9f0",e._sentryDebugIdIdentifier="sentry-dbid-44a2fb6c-fa8b-413f-835c-15f4ddf0b9f0")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:i,TimePicker:b,QuarterPicker:a,RangePicker:o}=s(d),u=f(n,{WeekPicker:t,MonthPicker:r,YearPicker:i,RangePicker:o,TimePicker:b,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.c909b87a.js.map
