import{d as i,o as p,c as a,w as n,b as m,u as t}from"./index.a1506152.js";import"./linters.93616ccb.js";import{W as s}from"./workspaces.83dc73e2.js";import{C as d}from"./ContentLayout.b536adcf.js";import{a as f}from"./controller.ba0b57fd.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.020fd9d1.js";import"./asyncComputed.5f4a7018.js";import"./workspaceStore.ee989c1a.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";import"./record.d6bf7292.js";import"./gateway.36e126ca.js";import"./popupNotifcation.7c2101f3.js";import"./fetch.8f81a728.js";import"./PhPencil.vue.34413cfd.js";import"./SaveButton.2182dde6.js";import"./UnsavedChangesHandler.f60d6853.js";import"./ExclamationCircleOutlined.37c8ef64.js";import"./CrudView.d781e8fd.js";import"./router.2d44d6fc.js";import"./Badge.07d26512.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.30c09690.js";import"./BookOutlined.989c2e9e.js";import"./PhDotsThreeVertical.vue.0cdf9efb.js";import"./index.a25bcd68.js";import"./index.4f812115.js";import"./polling.efadd48a.js";import"./index.aeb74054.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="9a56ae28-b137-4642-a94c-cb3a038ad256",o._sentryDebugIdIdentifier="sentry-dbid-9a56ae28-b137-4642-a94c-cb3a038ad256")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(p(),a(d,null,{default:n(()=>[m(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.af940e8f.js.map
