import{d as a}from"./workspaceStore.ee989c1a.js";import{e as o}from"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1e4742cd-609d-401e-a87a-3faa84a5d64f",e._sentryDebugIdIdentifier="sentry-dbid-1e4742cd-609d-401e-a87a-3faa84a5d64f")}catch{}})();const c=a("omniChat",()=>{const e=o(!1),n=o(!1),t=()=>{n.value=!0},s=()=>{n.value=!1};return{isOpen:e,isInputFocused:n,focusInput:t,blurInput:s,open:()=>{e.value=!0,t()},close:()=>{e.value=!1,s()}}});export{c as u};
//# sourceMappingURL=omniChatStore.fb3f9447.js.map
