.container[data-v-f3e7f5b0]{display:flex;flex-direction:column;justify-content:space-between;align-items:center;height:100%;width:0;border-left:1px solid #f0f0f0;transition:width .3s ease;overflow:hidden;background-color:#fff}.container.visible[data-v-f3e7f5b0]{width:25vw;overflow:visible}.container .upper[data-v-f3e7f5b0]{width:100%;padding:4px 12px}.container .upper .recent-container[data-v-f3e7f5b0]{overflow:scroll}.container .upper .recent-container[data-v-f3e7f5b0]::-webkit-scrollbar{display:none}.container .upper .recent-container .recent-thread[data-v-f3e7f5b0]{cursor:pointer}.container .upper[data-v-f3e7f5b0] .ant-btn{height:fit-content}.container .upper[data-v-f3e7f5b0] .ant-btn-icon-only{display:flex;justify-content:center;align-items:center;width:22px}.container .content[data-v-f3e7f5b0]{flex:1;flex-direction:column;overflow-y:auto;padding:18px;text-align:left;width:100%}.container .content .empty-container[data-v-f3e7f5b0]{height:100%}.container .content .entry[data-v-f3e7f5b0]{padding-top:4px;padding-bottom:12px}.container .content .entry .entry-owner[data-v-f3e7f5b0]{display:flex;gap:4px;align-items:center;margin-bottom:4px}.container .content .entry .entry-owner .avatar[data-v-f3e7f5b0]{display:flex;justify-content:center;align-items:center;margin-right:2px;font-size:12px!important}.container .lower[data-v-f3e7f5b0]{border:1px solid #f0f0f0;border-radius:10px;width:calc(100% - 20px);margin:10px 0;height:100px}.container .lower .bottom-lower[data-v-f3e7f5b0]{padding:6px}.container .lower .bottom-lower .info[data-v-f3e7f5b0]{display:flex;gap:8px;padding-left:4px}
