import{C as a}from"./gateway.36e126ca.js";import"./index.a1506152.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="e2d9f9c7-b0f8-4822-a759-013ae1114a6d",r._sentryDebugIdIdentifier="sentry-dbid-e2d9f9c7-b0f8-4822-a759-013ae1114a6d")}catch{}})();class s{async list(e){return a.get(`organizations/${e}/folders`)}async create(e){return a.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return a.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return a.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder.c8e2cc5b.js.map
