import{d as h,eH as A,r as B,u as e,o as s,c as i,by as C,Y as f,b as a,w as t,aG as r,bT as d,a as m,dc as w,ea as _,cO as N,eq as I,e9 as L,ei as S,aS as g,S as D,$ as z,a0 as R}from"./index.a1506152.js";import{a as $}from"./asyncComputed.5f4a7018.js";import{G as T}from"./PhChats.vue.5cfe85f1.js";import{F as V}from"./PhSignOut.vue.0c72747b.js";import{C as q}from"./router.2d44d6fc.js";import{a as k}from"./gateway.36e126ca.js";import{A as E}from"./index.4f812115.js";import{A as F}from"./Avatar.52002437.js";import{B as G,A as H,b as O}from"./index.2864b188.js";import{B as P}from"./BookOutlined.989c2e9e.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[o]="8a205672-dd5f-4003-98c4-17d490619524",n._sentryDebugIdIdentifier="sentry-dbid-8a205672-dd5f-4003-98c4-17d490619524")}catch{}})();const j={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},M={style:{display:"flex","flex-direction":"column",gap:"10px"}},U={style:{display:"flex",gap:"5px"}},Y=h({__name:"LoginBlock",setup(n){function o(y){const b=y.split("@")[0];return I.exports.kebabCase(b).toUpperCase().split("-").slice(0,2).map(p=>p[0]).join("")}const c=A(),{result:l,loading:u,refetch:x}=$(async()=>k.getAuthor());function v(){k.removeAuthor(),q.shutdown(),x(),c.push({name:"login"})}return(y,b)=>{const p=B("RouterLink");return e(u)?(s(),i(e(C),{key:0})):e(l)?(s(),f("div",j,[a(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e(T),{size:18})]),default:t(()=>[r(" Support ")]),_:1}),a(e(N),{placement:"bottomRight"},{content:t(()=>[m("div",M,[a(e(w),{size:"small",type:"secondary"},{default:t(()=>[r(_(e(l).claims.email),1)]),_:1}),a(e(d),{type:"text",onClick:v},{default:t(()=>[m("div",U,[a(e(V),{size:"20"}),r(" Logout ")])]),_:1})])]),default:t(()=>[a(e(E),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(F),{shape:"square"},{default:t(()=>[r(_(o(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(s(),i(e(d),{key:2},{default:t(()=>[a(p,{to:"/login"},{default:t(()=>[r("Login")]),_:1})]),_:1}))}}}),J={class:"extra"},K=h({__name:"Navbar",props:{breadcrumb:{}},setup(n){return(o,c)=>(s(),i(e(O),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[o.breadcrumb?(s(),i(e(G),{key:0},{default:t(()=>[(s(!0),f(g,null,L(o.breadcrumb,(l,u)=>(s(),i(e(H),{key:u},{default:t(()=>[a(e(S),{to:l.path},{default:t(()=>[r(_(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),extra:t(()=>[m("div",J,[a(e(d),{class:"docs-button",href:"https://abstra.io/docs/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(P))]),default:t(()=>[o.$slots.default?z(o.$slots,"default",{key:0},void 0,!0):(s(),f(g,{key:1},[r("Docs")],64))]),_:3}),a(Y)])]),_:3}))}});const ne=R(K,[["__scopeId","data-v-89ff1b2a"]]);export{ne as N};
//# sourceMappingURL=Navbar.c14c43a5.js.map
