import{b as l,eg as o,eM as u}from"./index.a1506152.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="497c412b-00c9-44e5-a0ac-f68bc22ec636",e._sentryDebugIdIdentifier="sentry-dbid-497c412b-00c9-44e5-a0ac-f68bc22ec636")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(c){return Object.getOwnPropertyDescriptor(n,c).enumerable}))),r.forEach(function(c){f(e,c,n[c])})}return e}function f(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=i({},t,n.attrs);return l(o,i({},r,{icon:u}),null)};a.displayName="ExclamationCircleOutlined";a.inheritAttrs=!1;const s=a;export{s as E};
//# sourceMappingURL=ExclamationCircleOutlined.37c8ef64.js.map
