import{O as r}from"./workspaceStore.ee989c1a.js";import{d as i,X as l,o as u,Y as c,b as t,w as n,u as d,aG as o,dd as f,dc as b}from"./index.a1506152.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="5a7656d3-6adf-4a0d-aa47-ab5c48a6b489",e._sentryDebugIdIdentifier="sentry-dbid-5a7656d3-6adf-4a0d-aa47-ab5c48a6b489")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(a,s)=>(u(),c("div",null,[t(d(f),null,{default:n(()=>[o("You're authenticated")]),_:1}),t(d(b),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.bd3b33f0.js.map
