import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.39819272.js";import{R as f}from"./tasksController.52908521.js";import{d as _,ef as b,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.a1506152.js";import"./gateway.36e126ca.js";import{a as j,B as x}from"./build.b53e3937.js";import{a as C}from"./project.16717559.js";import"./tables.ca746641.js";import{a as D}from"./asyncComputed.5f4a7018.js";import"./metadata.fcd21e8c.js";import"./PhRobot.vue.189c1747.js";import"./PhWebhooksLogo.vue.462865ef.js";import"./ant-design.2f4e4d05.js";import"./string.a9f2e2e2.js";import"./dayjs.c909b87a.js";import"./index.a25bcd68.js";import"./linters.93616ccb.js";import"./scripts.945184b7.js";import"./record.d6bf7292.js";import"./polling.efadd48a.js";import"./popupNotifcation.7c2101f3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="79b22ed9-501e-4a1c-a106-d13efef9f750",e._sentryDebugIdIdentifier="sentry-dbid-79b22ed9-501e-4a1c-a106-d13efef9f750")}catch{}})();const U=_({__name:"Tasks",setup(e){const a=b().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(c=>c.latest);if(!r)return null;const[u,d]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:d}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.3ae5054a.js.map
