import{d as i,eH as f,ef as m,o as l,c as p,w as c,u as n,Y as _,e9 as g,b as y,a as v,ea as w,aS as k}from"./index.a1506152.js";import{A as I,T}from"./TabPane.15ef770b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="bcb3b2f0-22c2-475e-9d0b-605d7de4a608",e._sentryDebugIdIdentifier="sentry-dbid-bcb3b2f0-22c2-475e-9d0b-605d7de4a608")}catch{}})();const B=i({__name:"TablesTabs",setup(e){const a=f(),t=m(),d=String(t.name),u=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],b=o=>{a.push({name:String(o),params:{projectId:u}})};return(o,D)=>(l(),p(n(T),{"active-key":n(d),options:r,"onUpdate:activeKey":b},{default:c(()=>[(l(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:c(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{B as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.afabde44.js.map
