import"./App.vue_vue_type_style_index_0_lang.4e87d4f2.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.4e87d4f2.js";import"./workspaceStore.ee989c1a.js";import"./index.a1506152.js";import"./url.e9cfa1d3.js";import"./colorHelpers.d2604467.js";import"./PlayerConfigProvider.9f6f394b.js";import"./index.6a4da8c3.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="319c044c-25d2-464a-abd5-21ad5ad54b0d",d._sentryDebugIdIdentifier="sentry-dbid-319c044c-25d2-464a-abd5-21ad5ad54b0d")}catch{}})();export{c as default};
//# sourceMappingURL=App.7baf39d4.js.map
