import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.39819272.js";import{L as d}from"./tasksController.52908521.js";import{d as f,e as u,o as _,c as m,w as t,b as s,u as o,dd as b,aG as i,bT as y,dh as k,a0 as w}from"./index.a1506152.js";import{C as T}from"./ContentLayout.b536adcf.js";import{a as g}from"./ant-design.2f4e4d05.js";import"./metadata.fcd21e8c.js";import"./PhRobot.vue.189c1747.js";import"./PhWebhooksLogo.vue.462865ef.js";import"./string.a9f2e2e2.js";import"./dayjs.c909b87a.js";import"./index.a25bcd68.js";import"./gateway.36e126ca.js";import"./popupNotifcation.7c2101f3.js";import"./linters.93616ccb.js";import"./asyncComputed.5f4a7018.js";import"./scripts.945184b7.js";import"./record.d6bf7292.js";import"./polling.efadd48a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2b2b99ef-10bc-4725-91f5-ba69cd5ab785",e._sentryDebugIdIdentifier="sentry-dbid-2b2b99ef-10bc-4725-91f5-ba69cd5ab785")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new d,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(_(),m(T,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(b),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(y),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.0f514325.js.map
